# WrokPlayerAPI

[![npm version](https://img.shields.io/npm/v/workplayerapi.svg?style=flat-square)](https://www.npmjs.org/package/workplayerapi)
[![install size](https://packagephobia.now.sh/badge?p=workplayerapi)](https://packagephobia.now.sh/result?p=workplayerapi)

API para encapsulamento de chamadas REST para o projeto Work Player da Kyros Tecnologias.

## Instalando

Usando npm:

```bash
$ npm install workplayerapi
```

Usando bower:

```bash
$ bower install workplayerapi
```

Usando yarn:

```bash
$ yarn add workplayerapi
```

Usando cdn:

```html
<script src="https://unpkg.com/workplayerapi/dist/workplayerapi.min.js"></script>
```

## Validações

### E-mail

```js
import { validateEmail } from 'workplayerapi/global/validators';

let email = 'kimr@kyros.com.br';

// Passando o e-mail
if (validateEmail(email)) console.log('E-mail é válido!');
else console.log('E-mail é inválido');
```

### Senha

```js
import { validatePassword } from 'workplayerapi/global/validators';

let email = 'kimr@kyros.com.br';

// Passando o e-mail
if (validatePassword(email)) console.log('Senha é válida!');
else console.log('Senha é inválida');
```

### Usuário autenticado

```js
import { setToken } from 'workplayerapi/config/logged';

// Pegar o token persistido com o Redux
let token = 'token';

setToken(token);
```

## Serviços

### Login

```js
import { makeLogin } from 'workplayerapi/routes/login';

let email = 'kimr@kyros.com.br';
let senha = 'password';

// Passando o e-mail e senha
makeLogin(email, senha)
    .then((result) => {
              console.log(JSON.stringify(result));
});
```

#### Retorno
##### Sucesso
```json
{
  "login_success" : true,
  "message"       : null,
  "token"         : "",
  "user"          : {
    "userId"      : 3,
    "username"    : "kimr",
    "name"        : "Kim",
    "displayName" : "Kim Ruan Lopes",
    "companyId"   : 1,
    "companyName" : "KYROS TECNOLOGIA",
    "email"       : "kimr@kyros.com.br",
    "type"        : "MOBILE",
    "sub"         : "192.168.11.23",
    "iat"         : 1567083971,
    "exp"         : 1567084571,
    "iss"         : "http://www.kyros.com.br",
    "permissions" : ["WP.PROJECT.SEARCH","WP.PROJECT.SAVE","WP.PLAYER.SEARCH","WP.PLAYER.SAVE"],
    "scopes"      : ["WP.ADMIN"]
  }
}
```

##### Falha
```json
{
  "login_success" : false,
  "message"       : "AUTHFAILED",
  "token"         : null,
  "user"          : null
}
```

### Players

```js
import { getAllPlayers } from 'workplayerapi/routes/player';

// Passar todos os filtros necessários diretamente pela função
// Caso algum filtro não seja necessário, passar com valor 'null'
let departmentId = 1;
let teamId       = 1;
let name         = "Kim";
let pageSize     = 10;
let page         = 2;
let email        = 'kimr@kyros.com.br';
let functionId   = 1;

// Passando o e-mail e senha
getAllPlayers(departmentId, teamId, name, pageSize, page, email, functionId)
    .then((result) => console.log(JSON.stringify(result)));
```

#### Retorno
##### Sucesso
```json
{
  "message" : null,
  "players" : [
  {
    "id"             : 1252,
    "name"           : "Kim",
    "birthdate"      : "10/03/1997",
    "zipcode"        : "32608-224",
    "email"          : "kimr@kyros.com.br",
    "cellphone"      : null,
    "landline"       : null,
    "documentNumber" : "38228218930",
    "city"           : "Uberlândia",
    "department"     : "FABRICA",
    "departmentId"   : 3,
    "function"       : "ANALISTA DESENVOLVEDOR",
    "functionId"     : 3,
    "team"           : "Equipe de Desenvolvimento e Projetos Java",
    "teamId"         : 2
  }
  ]
}
```

##### Falha
```json
{
  "message" : "",
  "players" : null
}
```

###### NOTA
A API está sendo construída aos poucos, portanto qualquer dúvida ou caso seja encontrado algum bug, reportar na seção de Issues.

## Autor

Kim Ruan Lopes - Kyros Tecnologias

## Lisença

MIT
